@@ -7,13 +7,13 @@ set -o pipefail
 rustup update
 cargo upgrade
 cargo update
-cargo fmt --all --
+cargo fmt --all -- --check
 if ! test -z "$(git status --porcelain)"; then
   >&2 printf '%s\n' "error: uncommitted changes"
   exit 1
 fi
 
-shellcheck -e SC1090 res/wrap.sh
+shellcheck -e SC1090 res/wrapper/security-wrapper.sh
 cargo test
 cargo clippy --all-targets --features= -- -D warnings
 cargo publish
