@@ -70,7 +70,9 @@ Sources are downloaded using .SRCINFO only"
 		#[structopt(help = "Target package", multiple = true, required = true)]
 		target: Vec<String>,
 	},
-	#[structopt(about = "Opens AUR web search page")]
+	#[structopt(
+		about = "Search for packages by name or description. If multiple keywords are used, all of them must match."
+	)]
 	Search {
 		#[structopt(help = "Target to search for", multiple = true, required = true)]
 		target: Vec<String>,
@@ -104,7 +106,7 @@ Supports: git, hg, bzr, svn, cvs, darcs. Currently by suffix only."
 		devel: bool,
 		#[structopt(
 			long = "printonly",
-			help = "Print the list of outdated packages to stdout, delimited by newline. Don't upgrade anything, don't ask questions (for use in scripts)."
+			help = "Print the list of outdated packages to stdout, delimited by newline. Don't upgrade anything, don't ask questions (for use in scripts). Exits with code 7 if no upgrades are available."
 		)]
 		printonly: bool,
 		#[structopt(
