@@ -18,7 +18,9 @@ use std::process::Command;
 
 /// All directories must exist upon `RuaPaths` creation.
 pub struct RuaPaths {
-	/// Subdirectory of ~/.cache/rua where packages are built after review
+	/// Subdirectory of ~/.cache/rua where packages are built after review.
+	/// Note: if you need to access a particular package's directory,
+	/// use `build_dir(pkgbase: &str)` instead
 	pub global_build_dir: PathBuf,
 	/// Subdirectory of ~/.config/rua where the package is reviewed by user, and changes are kept
 	global_review_dir: PathBuf,
@@ -237,10 +239,10 @@ fn show_legacy_dir_warnings(dirs: &ProjectDirs, correct_dir: &Path) {
 
 pub const SHELLCHECK_WRAPPER: &str = include_str!("../res/shellcheck-wrapper");
 pub const SECCOMP_BPF: &[u8] = include_bytes!(concat!(env!("OUT_DIR"), "/seccomp.bpf"));
-pub const WRAP_SH: &[u8] = include_bytes!("../res/wrap.sh");
-pub const WRAP_ARGS_EXAMPLE: &[u8] = include_bytes!("../res/wrap_args.sh.example");
+pub const WRAP_SH: &[u8] = include_bytes!("../res/wrapper/security-wrapper.sh");
+pub const WRAP_ARGS_EXAMPLE: &[u8] = include_bytes!("../res/wrapper/wrap_args.sh.example");
 pub const CONFIG_LOADER: &[u8] = include_bytes!("../res/print_makepkg_config.sh");
 
-pub const WRAP_SCRIPT_PATH: &str = ".system/wrap.sh";
+pub const WRAP_SCRIPT_PATH: &str = ".system/security-wrapper.sh";
 pub const MAKEPKG_CONFIG_LOADER_PATH: &str = ".system/print_makepkg_config.sh";
 pub const SECCOMP_PATH: &str = ".system/seccomp.bpf";
